@@ -12,13 +12,13 @@
         <translation type="obsolete">Příklad HexEdit je krátká ukázka doplňku QHexEdit.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="122"/>
         <source>Save As</source>
         <translation>Uložit jako</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="110"/>
         <location filename="../mainwindow.cpp" line="132"/>
+        <location filename="../mainwindow.cpp" line="154"/>
         <source>Save To Readable File</source>
         <translation>Uložit do čitelného souboru</translation>
     </message>
@@ -27,220 +27,225 @@
         <translation type="obsolete">HexEdit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="61"/>
+        <location filename="../mainwindow.cpp" line="37"/>
+        <source>The file has been modified.</source>
+        <translation>Soubor byl upraven.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="38"/>
+        <source>Do you want to save your changes?</source>
+        <translation>Chcete uložit své změny?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="82"/>
         <source>About QHexEdit</source>
-        <translation type="unfinished"></translation>
+        <translation>O QHEXEDIT</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="62"/>
+        <location filename="../mainwindow.cpp" line="83"/>
         <source>The QHexEdit example is a short Demo of the QHexEdit Widget.</source>
-        <translation type="unfinished"></translation>
+        <translation>Příklad QHExEdit je krátkým demem widgetu QHExEdit.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="115"/>
         <location filename="../mainwindow.cpp" line="137"/>
-        <location filename="../mainwindow.cpp" line="347"/>
-        <location filename="../mainwindow.cpp" line="399"/>
+        <location filename="../mainwindow.cpp" line="159"/>
+        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../mainwindow.cpp" line="441"/>
         <source>QHexEdit</source>
-        <translation type="unfinished"></translation>
+        <translation>Qhexedit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="116"/>
         <location filename="../mainwindow.cpp" line="138"/>
+        <location filename="../mainwindow.cpp" line="160"/>
         <source>Cannot write file %1:
 %2.</source>
         <translation>Nelze zapsat soubor %1:
 %2.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="126"/>
         <location filename="../mainwindow.cpp" line="148"/>
-        <location filename="../mainwindow.cpp" line="406"/>
+        <location filename="../mainwindow.cpp" line="170"/>
+        <location filename="../mainwindow.cpp" line="448"/>
         <source>File saved</source>
         <translation>Soubor uložen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="162"/>
+        <location filename="../mainwindow.cpp" line="184"/>
         <source>Overwrite</source>
         <translation>Přepsat</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="164"/>
+        <location filename="../mainwindow.cpp" line="186"/>
         <source>Insert</source>
         <translation>Vložit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="210"/>
+        <location filename="../mainwindow.cpp" line="238"/>
         <source>&amp;Open...</source>
         <translation>&amp;Otevřít...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="212"/>
+        <location filename="../mainwindow.cpp" line="240"/>
         <source>Open an existing file</source>
         <translation>Otevřít stávající soubor</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="215"/>
+        <location filename="../mainwindow.cpp" line="243"/>
         <source>&amp;Save</source>
         <translation>&amp;Uložit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="217"/>
+        <location filename="../mainwindow.cpp" line="245"/>
         <source>Save the document to disk</source>
         <translation>Uložit dokument na disk</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="220"/>
+        <location filename="../mainwindow.cpp" line="248"/>
         <source>Save &amp;As...</source>
         <translation>Uložit &amp;jako...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="222"/>
+        <location filename="../mainwindow.cpp" line="250"/>
         <source>Save the document under a new name</source>
         <translation>Uložit dokument pod novým názvem</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="225"/>
+        <location filename="../mainwindow.cpp" line="253"/>
         <source>Save &amp;Readable...</source>
         <translation>Uložit Č&amp;itelné...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="226"/>
+        <location filename="../mainwindow.cpp" line="254"/>
         <source>Save document in readable form</source>
         <translation>Uložit dokument v čitelné podobě</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="229"/>
+        <location filename="../mainwindow.cpp" line="257"/>
         <source>E&amp;xit</source>
         <translation>&amp;Ukončit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="231"/>
+        <location filename="../mainwindow.cpp" line="259"/>
         <source>Exit the application</source>
         <translation>Ukončit program</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="234"/>
+        <location filename="../mainwindow.cpp" line="262"/>
         <source>&amp;Undo</source>
         <translation>&amp;Zpět</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="238"/>
+        <location filename="../mainwindow.cpp" line="266"/>
         <source>&amp;Redo</source>
         <translation>&amp;Znovu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="242"/>
+        <location filename="../mainwindow.cpp" line="270"/>
         <source>&amp;Save Selection Readable...</source>
         <translation>&amp;Uložit výběr čitelný...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="243"/>
+        <location filename="../mainwindow.cpp" line="271"/>
         <source>Save selection in readable form</source>
         <translation>Uložit výběr v čitelné podobě</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="246"/>
+        <location filename="../mainwindow.cpp" line="274"/>
         <source>&amp;About</source>
         <translation>&amp;O programu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="247"/>
+        <location filename="../mainwindow.cpp" line="275"/>
         <source>Show the application&apos;s About box</source>
         <translation>Ukázat informace o programu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="250"/>
+        <location filename="../mainwindow.cpp" line="278"/>
         <source>About &amp;Qt</source>
         <translation>O &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="251"/>
+        <location filename="../mainwindow.cpp" line="279"/>
         <source>Show the Qt library&apos;s About box</source>
         <translation>Ukázat informace oknihovně Qt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="261"/>
+        <location filename="../mainwindow.cpp" line="289"/>
         <source>Find next occurrence of the searched pattern</source>
-        <translation type="unfinished"></translation>
+        <translation>Najděte další výskyt prohledaného vzoru</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="264"/>
+        <location filename="../mainwindow.cpp" line="292"/>
         <source>&amp;Options</source>
         <translation>&amp;Volby</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="265"/>
+        <location filename="../mainwindow.cpp" line="293"/>
         <source>Show the Dialog to select applications options</source>
         <translation>Ukázat dialog pro výběr voleb programu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="337"/>
+        <location filename="../mainwindow.cpp" line="365"/>
         <source>Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Upravit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="400"/>
+        <location filename="../mainwindow.cpp" line="442"/>
         <source>Cannot write file %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nelze psát soubor %1.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="254"/>
+        <location filename="../mainwindow.cpp" line="282"/>
         <source>&amp;Find/Replace</source>
-        <translation type="unfinished"></translation>
+        <translation>\ Najít/vyměnit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="41"/>
-        <source>Drop File: </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="256"/>
+        <location filename="../mainwindow.cpp" line="284"/>
         <source>Show the Dialog for finding and replacing</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobrazit dialog pro nalezení a výměnu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="259"/>
+        <location filename="../mainwindow.cpp" line="287"/>
         <source>Find &amp;next</source>
-        <translation type="unfinished"></translation>
+        <translation>Najít \ Další</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="271"/>
+        <location filename="../mainwindow.cpp" line="299"/>
         <source>&amp;File</source>
         <translation>&amp;Soubor</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="279"/>
+        <location filename="../mainwindow.cpp" line="307"/>
         <source>&amp;Edit</source>
         <translation>Ú&amp;pravy</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="289"/>
+        <location filename="../mainwindow.cpp" line="317"/>
         <source>&amp;Help</source>
         <translation>&amp;Nápověda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="298"/>
+        <location filename="../mainwindow.cpp" line="326"/>
         <source>Address:</source>
         <translation>Adresa:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="309"/>
+        <location filename="../mainwindow.cpp" line="337"/>
         <source>Size:</source>
         <translation>Velikost:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="320"/>
+        <location filename="../mainwindow.cpp" line="348"/>
         <source>Mode:</source>
         <translation>Režim:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="329"/>
+        <location filename="../mainwindow.cpp" line="357"/>
         <source>Ready</source>
         <translation>Připraven</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="334"/>
+        <location filename="../mainwindow.cpp" line="362"/>
         <source>File</source>
         <translation>Soubor</translation>
     </message>
@@ -249,14 +254,14 @@
         <translation type="vanished">SDI</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="348"/>
+        <location filename="../mainwindow.cpp" line="376"/>
         <source>Cannot read file %1:
 %2.</source>
         <translation>Nelze číst soubor %1:
 %2.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="354"/>
+        <location filename="../mainwindow.cpp" line="382"/>
         <source>File loaded</source>
         <translation>Soubor nahrán</translation>
     </message>
@@ -270,7 +275,7 @@
     <message>
         <location filename="../optionsdialog.ui" line="14"/>
         <source>QHexEdit - Options</source>
-        <translation type="unfinished"></translation>
+        <translation>QHexEdit - Možnosti</translation>
     </message>
     <message>
         <location filename="../optionsdialog.ui" line="20"/>
@@ -278,9 +283,13 @@
         <translation>Příznaky</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="26"/>
         <source>ReadOnly</source>
-        <translation>PouzeProČtení</translation>
+        <translation type="vanished">PouzeProČtení</translation>
+    </message>
+    <message>
+        <location filename="../optionsdialog.ui" line="26"/>
+        <source>Damic Bytes per Line</source>
+        <translation>Damické bajty na řádek</translation>
     </message>
     <message>
         <location filename="../optionsdialog.ui" line="33"/>
@@ -294,59 +303,101 @@
     </message>
     <message>
         <location filename="../optionsdialog.ui" line="47"/>
-        <location filename="../optionsdialog.ui" line="195"/>
+        <source>Read only</source>
+        <translation>Číst pouze</translation>
+    </message>
+    <message>
+        <location filename="../optionsdialog.ui" line="54"/>
+        <location filename="../optionsdialog.ui" line="165"/>
         <source>Address Area</source>
         <translation>Oblast s adresou</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="54"/>
+        <location filename="../optionsdialog.ui" line="61"/>
         <source>Ascii Area</source>
         <translation>Oblast ASCII</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="64"/>
+        <location filename="../optionsdialog.ui" line="77"/>
         <source>Colors and Fonts</source>
         <translation>Barvy a písma</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="70"/>
+        <location filename="../optionsdialog.ui" line="108"/>
         <source>Highlighting Color</source>
         <translation>Barva pro zvýraznění</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="102"/>
         <source>Address Area Color</source>
-        <translation>Barva pro oblast s adresou</translation>
+        <translation type="vanished">Barva pro oblast s adresou</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="159"/>
         <source>Selection Color</source>
-        <translation>Barva výběru</translation>
+        <translation type="vanished">Barva výběru</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="166"/>
+        <source>Address Font Color</source>
+        <translation type="vanished">Adresujte barvu písma</translation>
+    </message>
+    <message>
+        <source>ASCII Area Color</source>
+        <translation type="vanished">Barva oblasti ASCII</translation>
+    </message>
+    <message>
+        <source>ASCII Font Color</source>
+        <translation type="vanished">ASCII Písmo barvy</translation>
+    </message>
+    <message>
+        <source>Hex Font Color</source>
+        <translation type="vanished">Hexní písmo barva</translation>
+    </message>
+    <message>
+        <location filename="../optionsdialog.ui" line="115"/>
         <source>Widget Font</source>
         <translation>Písmo doplňku</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="185"/>
+        <location filename="../optionsdialog.ui" line="134"/>
         <source>01 23 45 67 89 ab cd ef</source>
         <translation>01 23 45 67 89 ab cd ef</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="201"/>
+        <location filename="../optionsdialog.ui" line="142"/>
+        <source>Default Mode</source>
+        <translation>Výchozí režim</translation>
+    </message>
+    <message>
+        <location filename="../optionsdialog.ui" line="147"/>
+        <source>Dark Mode</source>
+        <translation>Tmavý režim</translation>
+    </message>
+    <message>
+        <location filename="../optionsdialog.ui" line="155"/>
+        <source>Palette</source>
+        <translation>Paleta</translation>
+    </message>
+    <message>
+        <location filename="../optionsdialog.ui" line="171"/>
         <source>Address Area Width</source>
         <translation>Šířka oblasti s adresou</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="224"/>
+        <location filename="../optionsdialog.ui" line="194"/>
         <source>Hex Area</source>
-        <translation type="unfinished"></translation>
+        <translation>Hex oblast</translation>
     </message>
     <message>
-        <location filename="../optionsdialog.ui" line="230"/>
+        <location filename="../optionsdialog.ui" line="200"/>
         <source>Bytes per Line</source>
-        <translation type="unfinished"></translation>
+        <translation>Bajty na řádek</translation>
+    </message>
+</context>
+<context>
+    <name>QHexEdit</name>
+    <message>
+        <location filename="../main.cpp" line="82"/>
+        <source>A hex editor application</source>
+        <translation>Aplikace hexového editoru</translation>
     </message>
 </context>
 <context>
@@ -358,103 +409,103 @@
     <message>
         <location filename="../searchdialog.ui" line="14"/>
         <source>QHexEdit - Find/Replace</source>
-        <translation type="unfinished"></translation>
+        <translation>QHexEdit - Find/Export</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="22"/>
         <source>Find</source>
-        <translation type="unfinished"></translation>
+        <translation>Nalézt</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="29"/>
         <location filename="../searchdialog.ui" line="65"/>
         <source>Hex</source>
-        <translation type="unfinished"></translation>
+        <translation>Hex</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="34"/>
         <location filename="../searchdialog.ui" line="70"/>
         <source>UTF-8</source>
-        <translation type="unfinished"></translation>
+        <translation>UTF-8</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="58"/>
         <source>Replace</source>
-        <translation type="unfinished"></translation>
+        <translation>Nahradit</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="94"/>
         <source>Options</source>
-        <translation type="unfinished"></translation>
+        <translation>Možnosti</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="100"/>
         <source>&amp;Backwards</source>
-        <translation type="unfinished"></translation>
+        <translation>\Zpět</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="107"/>
         <source>&amp;Prompt on replace</source>
-        <translation type="unfinished"></translation>
+        <translation>\ Výzva na vyměměte</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="121"/>
         <source>&amp;Find</source>
-        <translation type="unfinished"></translation>
+        <translation>\Nalézt</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="124"/>
         <source>F3</source>
-        <translation type="unfinished"></translation>
+        <translation>F3</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="134"/>
         <source>&amp;Replace</source>
-        <translation type="unfinished"></translation>
+        <translation>\Nahradit</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="141"/>
         <source>Replace &amp;All</source>
-        <translation type="unfinished"></translation>
+        <translation>Nahraďte \ všechny</translation>
     </message>
     <message>
         <location filename="../searchdialog.ui" line="148"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>\Blízko</translation>
     </message>
     <message>
         <location filename="../searchdialog.cpp" line="73"/>
         <location filename="../searchdialog.cpp" line="99"/>
         <source>QHexEdit</source>
-        <translation type="unfinished"></translation>
+        <translation>Qhexedit</translation>
     </message>
     <message>
         <location filename="../searchdialog.cpp" line="73"/>
         <source>%1 occurrences replaced.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nahrazeno %1 výskyty.</translation>
     </message>
     <message>
         <location filename="../searchdialog.cpp" line="100"/>
         <source>Replace occurrence?</source>
-        <translation type="unfinished"></translation>
+        <translation>Nahradit výskyt?</translation>
     </message>
 </context>
 <context>
     <name>UndoStack</name>
     <message>
-        <location filename="../../src/commands.cpp" line="112"/>
+        <location filename="../../src/commands.cpp" line="115"/>
         <source>Inserting %1 bytes</source>
-        <translation type="unfinished"></translation>
+        <translation>Vkládání %1 bajtů</translation>
     </message>
     <message>
-        <location filename="../../src/commands.cpp" line="134"/>
+        <location filename="../../src/commands.cpp" line="137"/>
         <source>Delete %1 chars</source>
-        <translation type="unfinished"></translation>
+        <translation>Odstranit %1 znaky</translation>
     </message>
     <message>
-        <location filename="../../src/commands.cpp" line="159"/>
+        <location filename="../../src/commands.cpp" line="162"/>
         <source>Overwrite %1 chars</source>
-        <translation type="unfinished"></translation>
+        <translation>Přepsat %1 chars</translation>
     </message>
 </context>
 </TS>
